# Load the HistData package to access the SnowMap function
library(HistData)

# Generate Snow's Cholera Map of London with specified parameters
SnowMap(
  # Set the limits of the x-axis (longitude) for the map
  xlim = c(3, 20),
  # Set the limits of the y-axis (latitude) for the map
  ylim = c(3, 20),
  # Hide axis labels
  axis.labels = FALSE,
  # Set the main title for the map
  main = "Snow's Cholera Map of London",
  # Include a scale on the map
  scale = TRUE,
  # Hide polygons
  polygons = FALSE,
  # Hide density information
  density = FALSE,
  # Define arguments for the streets layer
  streets.args = list(col = "grey", lwd = 1),
  # Define arguments for the cholera deaths layer
  deaths.args = list(col = "red", pch = 15, cex = 0.6),
  # Define arguments for the water pumps layer
  pumps.args = list(col = "blue", pch = 17, cex = 1.5, cex.lab = 0.9),
  # Define arguments for the scale
  scale.args = list(xs = 3.5, ys = 19.7),
  # Define arguments for the polygons layer
  polygons.args = list(col = NA, border = "brown", lwd = 2, lty = 1),
  # Define arguments for density information
  density.args = list(
    bandwidth = c(0.5, 0.5),
    col1 = rgb(0, 1, 0, 0),
    col2 = rgb(1, 0, 0, .8)
  )
)

# Display a plot with specified limits and title
Splot(
  xlim = c(3, 20),
  ylim = c(3, 20),
  xlab = "",
  ylab = "",
  axis.labels = FALSE,
  main = "Snow's Cholera Map of London"
)

# Display cholera deaths on the map with specified color, shape, and size
Sdeaths(col = "red", pch = 15, cex = 0.6)

# Display water pumps on the map with specified color, shape, size, and label size
Spumps(col = "blue", pch = 17, cex = 1.5, cex.lab = 0.9)

# Display streets on the map with specified color and line width
Sstreets(col = "gray", lwd = 1)

# Display the scale on the map at specified position
Sscale(xs = 3.5, ys = 19.7)

# Display polygons on the map with specified border color, line width, and line type
Spolygons(col = NA, border = "brown", lwd = 2, lty = 1)

# Display density information on the map with specified bandwidth and colors
Sdensity(bandwidth = c(0.5, 0.5), col1 = rgb(0, 1, 0, 0), col2 = rgb(1, 0, 0, 0.8))

